@@ -21,11 +21,11 @@ class Request(object):
     max_post_size = None  # максимальный размер post-данных
     _new_flashes = None
     _clear_flashes = False
-    
+
     def __init__(self, environ):
         self.environ = environ
         self.path = environ['PATH_INFO'].decode(self.charset, self.encoding_errors)
-    
+
     @cached_property
     def context(self):
         res = {'rq': self, 'url4': url4, 'cfg': cfg}
@@ -42,7 +42,7 @@ class Request(object):
         return MultiDict((k.decode(self.charset, self.encoding_errors),
             v[-1].decode(self.charset, self.encoding_errors))
                 for k, v in cgi.parse_qs(self.environ['QUERY_STRING']).iteritems())
-        
+
     @cached_property
     def POST(self):
         '''
@@ -133,7 +133,7 @@ class Request(object):
     def url(self):
         '''Полный урл'''
         return '%s://%s%s' % (self.scheme, self.host, self.full_path)
-    
+
     @cached_property
     def ip(self):
         '''
@@ -167,11 +167,11 @@ class Request(object):
     @cached_property
     def referer(self):
         return self.environ.get('HTTP_REFERER', '')
-        
+
     @cached_property
     def user_agent(self):
         return self.environ.get('HTTP_USER_AGENT', '')
-    
+
     @cached_property
     def basic_user(self):
         if cfg.BASIC_AUTH_SSL_ONLY and self.scheme != 'https':
@@ -189,7 +189,7 @@ class Request(object):
         if cfg.BASIC_AUTH_DB.get(user) != sha1(passwd).hexdigest():
             raise BasicAuth
         return user
-        
+
     @cached_property
     def flashes(self):
         ret = []
@@ -214,7 +214,7 @@ class Response(Exception):
     charset = 'utf-8'  # дефолтная кодировка
     encoding_errors = 'ignore'
     content_type = 'text/html'  # дефолтный Content-Type
-    
+
     def __init__(self, body='', headers=None, cookies=None, **kwargs):
         '''
         Response
@@ -248,7 +248,7 @@ class Response(Exception):
         for k, v in kwargs.iteritems():
             self.COOKIES[key][k] = v
         return self
-        
+
     def delete_cookie(self, key):
         return self.set_cookie(key, '', expires=-1)
 
@@ -273,9 +273,9 @@ class Response(Exception):
         else:
             self.headers['Content-Type'] = self.content_type
         self.headers['Content-Length'] = str(len(self.body))
-        
+
         return status, list(self.headers.iterallitems()), [self.body]
-        
+
 
 class App(object):
     def __init__(self, cfg_module='cfg'):
@@ -283,7 +283,7 @@ class App(object):
             *cfg_module - модуль конфигурации
         '''
         self.cfg_module = cfg_module
-    
+
     def setup(self, environ, start_response):
         '''
         Первый запуск
@@ -302,7 +302,7 @@ class App(object):
                         raise
                 abort(404)
             return wrapper
-        
+
         try:
             cfg_module = obj_from_str(self.cfg_module)
         except ImportError:
@@ -316,7 +316,7 @@ class App(object):
         Request.max_post_size = cfg.POST_MAX_SIZE
         Response.charset = cfg.CHARSET
         add_apps(cfg.INSTALLED_APPS)
-        
+
         list_obj_from_str(cfg.CONTEXT_PROCESSORS)
         mdls = list_obj_from_str(cfg.MIDDLEWARES)
         self.request_middlewares = [m().process_request for m in mdls
@@ -369,11 +369,13 @@ def redirect(url, permanent=False, **kwargs):
     code = 301 if permanent else 302
     if not url.startswith(('/', 'http://', 'https://')):
         url = url4(url, **kwargs) or url
+    if isinstance(url, unicode):
+        url = url.encode('utf-8')
     return Response('', code=code, headers={'Location': url})
 
 def abort(code):
     raise HttpError(code)
-    
+
 
 HTTP_CODES = {
     100:    'Continue',
